Simple Module to depaginate Django Rest Framework results
----------------------------------------------------------

Contains a generator to yield Django Rest API results one at a time.
Check the test file for usage example

